# Updateinformationen zur EIDAS-Node v2.5

Die nachfolgende Beschreibung umfasst die Ergebnisse des Review der bestehenden, am 04.05.2021 übermittelten, Konfiguration der AT EIDAS-Node und liefert empfohlende Ändungen welche mit dem Update auf die EIDAS-Node Version 2.5 durchgeführt werden sollten.  Die nachfolgende Beschreibung gliedert sich nach einzelnen Konfigurationsdateien im Konfigurationsverzeichnis des EIDAS Nodes.



### 1. _eidas.xml_

Die beigelgte Datei _./config/eidas.xml_ ist die angepasste Version der am 04.05.2021 übermittelten Konfigurationsdatei. Nachfolgend eine kurze Zusammenfassung der darin vorgenommenen Anpassungen:

- **eIDAS Connector WhiteList**

Die Konfigurationselemente

```xml
<entry key="connector.metadata.location.whitelist"></entry>
<entry key="connector.url.redirect.location.whitelist"></entry>
<entry key="connector.url.post.location.whitelist"></entry>

<entry key="connector.url.redirect.location.whitelist"></entry>
<entry key="connector.url.post.location.whitelist"></entry>

```

 wurden bereits mit der Version v2.3 der EIDAS-Node entfernt und  durch eine Property basierte Konfiguration, siehe _./metadata/MetadataFetcher_Connector.properties_ und _./metadata/MetadataFetcher_Service.properties_ ersetzt. Details hierzu finden sich im Handbuch zur EIDAS-Node v2.5.

- **Whitelist Signing Algorithmen**

Die Whitelist für erlaubte Signaturalgorithmen beinhaltetet die Algorithmen http://www.w3.org/2001/04/xmldsig-more#rsa-sha256 , _http://www.w3.org/2001/04/xmldsig-more#rsa-sha384_, _http://www.w3.org/2001/04/xmldsig-more#rsa-sha512_ und _http://www.w3.org/2001/04/xmldsig-more#rsa-ripemd160_ welche entsprechend eIDAS Spezifikation nicht zulässig sind. Diese wurden entfernt.

```xml
<entry key="signature.algorithm.whitelist">
	http://www.w3.org/2007/05/xmldsig-more#sha256-rsa-MGF1;
	http://www.w3.org/2007/05/xmldsig-more#sha384-rsa-MGF1;
	http://www.w3.org/2007/05/xmldsig-more#sha512-rsa-MGF1;
	http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256;
	http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384;
	http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512
</entry>

```

- **Ländercode des EIDAS-Node Betreibers**

Mit der v2.5 und der eIDAS Spezifikation 1.2 wurde in den SAML2 Metadaten der Ländercode des eIDAS-Node betreibers publiziert. Dieser wird mittels folgendem Konfigurationsparameter festgelegt

```xml
<entry key="metadata.node.country">AT</entry>
```

- **Erlaubte TLS Versionen und Algorithmen**

Die bestehende EIDAS-Node Konfiguration verwendete und erlaubte Algorithmen welche entsprechend eIDAS Spezifikation nicht zulässig sind. Somit wurden folgende Konfigurationsparameter angepasst. Hierfür wurde _TLSv1.1_ entfernt

```xml
<entry key="tls.enabled.protocols">TLSv1.2</entry>
```

und die TLS Algorithem auf das erlaubte Set eingeschränkt.

```xml
<entry key="tls.enabled.ciphers">
	TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256,
	TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256,
	TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384,
	TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384,
	TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256,
	TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256,
	TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384,
	TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384,
	TLS_DHE_RSA_WITH_AES_128_CBC_SHA256,
	TLS_DHE_RSA_WITH_AES_128_GCM_SHA256,
	TLS_DHE_RSA_WITH_AES_256_CBC_SHA256,
	TLS_DHE_RSA_WITH_AES_256_GCM_SHA384,
	TLS_EMPTY_RENEGOTIATION_INFO_SCSV  
</entry>
```

- **Prüfung Minimum-Dataset-Attribute**

Die EIDAS-Node implementiert eine Prüfung ob zumindest das Minimim-Dataset übermittelt wird. Diese Prüfung ist in der aktuellen Konfiguration deaktiviert und wurde nun aktiviert.

```xml
<entry key="disable.check.mandatory.eidas.attributes">false</entry>
```

- **Versions-Identifier für eIDAS Metadaten**

Aus Interoperabilitätsgründen benötigt die EIDAS-Node die aktuell unterstützen Protokollversionen und die Version. Diese Parameter werden jedoch mittels Konfiguration definiert. Die entsprechenden Konfigurationsparameter wurden angepasst.

```xml
<entry key="eidas.protocol.version">1.2;1.1</entry>
<entry key="eidas.application.identifier">CEF:eIDAS-ref:2.5.0</entry>
```

- **Nicht mehr unterstütze Konfigurationsparameter**

Die nachfolgenden Parameter wurden gelöscht da diese in der EIDAS-Node v2.5 nicht mehr zur Verfügung stehen.

```xml
<entry key="connector.node.url">https://eidas.bmi.gv.at/EidasNode/</entry>
<entry key="service.node.url">https://eidas.bmi.gv.at/EidasNode/</entry>
```

- **Audit Logging für SAML Messages**

Aktiviert / Deaktiviert das AuditLog entsprechend der EIDAS-Node Dokumentation _eID Error and Event Logging v2.5.pdf_

```xml
<entry key="saml.audit">true</entry>
```



### 2. _SignModule_Connector.xml_

Die beigelgte Datei _./config/SignModule_Connector.xml_ ist die angepasste Version der am 04.05.2021 übermittelten Konfigurationsdatei. Nachfolgend eine kurze Zusammenfassung der darin vorgenommenen Anpassungen:

- **Signing Algorithmus**

Der aktuell verwendete Signaturalgorithmus _http://www.w3.org/2001/04/xmldsig-more#rsa-sha512_ ist entsprechend der eIDAS Spezifikation nicht zulässig und wurde durch _http://www.w3.org/2007/05/xmldsig-more#sha256-rsa-MGF1_ ersetzt

```xml
<entry key="signature.algorithm">http://www.w3.org/2007/05/xmldsig-more#sha256-rsa-MGF1</entry>	
```

- **Whitelist Signing Algorithmen**

Das nachfolgende Element wurde aus der Konfiguration entfernt da es nun via _eidas.xml_ abgebildet wird.

```xml
<entry key="signature.algorithm.whitelist">
	 http://www.w3.org/2001/04/xmldsig-more#rsa-sha256;
         http://www.w3.org/2001/04/xmldsig-more#rsa-sha384;
         http://www.w3.org/2001/04/xmldsig-more#rsa-sha512;
         http://www.w3.org/2001/04/xmldsig-more#rsa-ripemd160;
         http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha256;
         http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha384;
         http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha512;
         http://www.w3.org/2007/05/xmldsig-more#sha256-rsa-MGF1
</entry>
```



### 3. _igniteNode.xml_ und _igniteSpecificCommunication.xml_

Die beigelegten Dateien _./config/igniteNode.xml_ und _./config/igniteSpecificCommunication.xml_ entstammen der Beispielkonfiguration der EIDAS-Node v2.5 und dienen als Beispiel für potentiell notwendige Anpassungen. Nachfolgend eine kurze Zusammenfassung der potentiell erforderlichen Anpassungen:

- **Apache Ignite WorkDirectory**

```xml
<property name="workDirectory" value="/PATH_TO_WORK_DIRECTOR"/>
```

Ja nach Deployment und Infrastruktur kann es erforderlich sein das WorkDirektory der Apache Ignite Instanz explizit festzulegen da die Applikation in dieses Verzeichnis sowohl Lese- als auch Schreibzugriff benötigt

- **Expired Policy für Apache Ignite Caches**

Je nach aktuellem Konfigurationsstand ist es möglich, dass die aktuelle Apache Ignite Konfiguration keine ExpirePolicy für Element  im Cache definiert. Eine entsprechende Policy ist jedoch aus Betriebssicht zu empfehlen. Falls keine Policy vorhanden ist kann diese mittels dem nachfolgend beispielhaft dargestellten Konfigurationselemente aktiviert werden.

Der nachfolgende Konfigurationsblock definiert eine Expirationpolicy von 7 Minuten für Daten im Cache.

```xml
<!-- Defines expiry policy based on moment of creation for ignite cache. -->
<bean id="7_minutes_duration" class="javax.cache.expiry.CreatedExpiryPolicy" factory-method="factoryOf" scope="prototype">
	<constructor-arg>
		<bean class="javax.cache.expiry.Duration">
			<constructor-arg value="MINUTES"/>
			<constructor-arg value="7"/>
		</bean>
	</constructor-arg>
</bean> 
```



Anschließend kann diese Policy den einzelnen Caches, wie im nachfolgenden Bespiel exemplarisch gezeigt, zugeordnet werden.  Die Zuordnung erfolgt durch einfügen des Konfigurationsproperties _<property name="expiryPolicyFactory" ref="7_minutes_duration"/>_

```xml
....

<property name="cacheConfiguration">
	<list>
		<bean class="org.apache.ignite.configuration.CacheConfiguration">
			<property name="name" value="specificNodeConnectorRequestCache"/>
			<property name="atomicityMode" value="ATOMIC"/>
			<property name="backups" value="1"/>
			<property name="expiryPolicyFactory" ref="7_minutes_duration"/>
		</bean>
....
```

Da sowohl in der Konfiguration _igniteNode.xml_ als auch in der Konfiguration _igniteSpecificCommunication.xml_ mehrere Caches mit unterschiedlichen Expiration-Timeouts definieren empfehlen wir die Konfigurationsparameter entsprechend er beigelegten Beispielkonfiguration zu übernehmen.

- **Apache Ignite SSL Kommunikation**

Der EIDAS-Node und er MS-specific eIDAS-Connector kommunizieren via Apache Ignite und shared Caches. Die Kommunikation zwischeen den einzelnen Apache Ignite Nodes kann hierbei auch verschlüsselt via SSL erfolgen. SSL Kommunikation kann mittels des nachfolgenden Konfigurationsblocks aktiviert werden.

```xml
<property name="sslContextFactory">
	<bean class="org.apache.ignite.ssl.SslContextFactory">
		<!--uncomment the below keyAlgorithm when IBM JRE is used e.g. websphere 8.5.5-->
		<!--<property name="keyAlgorithm" value="IBMX509" />-->
		<property name="keyStoreFilePath" value="${EIDAS_CONFIG_REPOSITORY}/ignite/KeyStore/server.jks"/>
		<property name="keyStorePassword" value="123456"/>
		<property name="trustStoreFilePath" value="${EIDAS_CONFIG_REPOSITORY}/ignite/KeyStore/trust.jks"/>
		<property name="trustStorePassword" value="123456"/>
		<property name="protocol" value="TLSv1.2"/>
	</bean>
</property>
```

